==> kbarcode-trinity_3.5.13.2.orig.tar.xz: kbarcode-trinity-3.5.13.2/kbarcode/multilineeditdlg.h <==
/***************************************************************************
                          multilineeditdlg.h  -  description
                             -------------------
    begin                : Sam Jan 11 2003
    copyright            : (C) 2003 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MULTILINEEDITDLG_H
#define MULTILINEEDITDLG_H

#include <tqwidget.h>
#include "documentitem.h"

class KActionCollection;
class KToggleAction;
class KFontAction;
class KFontSizeAction;
class KToolBar;
class KSpell;
class KSpellConfig;
class DSTextEdit;
class TokenProvider;

class MultiLineEditor : public TQWidget {
    Q_OBJECT
  TQ_OBJECT
    public:
        MultiLineEditor( TokenProvider* token, TQWidget *parent=0, const char *name=0);
        ~MultiLineEditor();
        TQString text();
        void setText( const TQString & t );
        
    private slots:
        void setupActions();
        void updateActions();
        void spellCheckDone(const TQString & buffer);

        void save();
        void updateFont();
        void updateCharFmt();
        void updateAligment();
        void formatColor();
        void checkSpelling();
        void setAlignLeft( bool yes );
        void setAlignRight( bool yes );
        void setAlignCenter( bool yes );
        void setAlignJustify( bool yes );               
        void insertNewField();
        
    protected:
        TokenProvider* m_token;

	DSTextEdit* editor;
        
        KActionCollection* ac;
        
        KToggleAction *action_bold;
        KToggleAction *action_italic;
        KToggleAction *action_underline;

        KFontAction *action_font;
        KFontSizeAction *action_font_size;

        KToggleAction *action_align_left;
        KToggleAction *action_align_right;
        KToggleAction *action_align_center;
        KToggleAction *action_align_justify;

        KToolBar* toolBar;
        KToolBar* tool2Bar;
        KToolBar* tool3Bar;

        KSpell* spell;
};

#endif

==> kbarcode-trinity_14.0.13.orig.tar.xz: kbarcode-trinity-14.0.13/kbarcode/multilineeditdlg.h <==
/***************************************************************************
                          multilineeditdlg.h  -  description
                             -------------------
    begin                : Sam Jan 11 2003
    copyright            : (C) 2003 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MULTILINEEDITDLG_H
#define MULTILINEEDITDLG_H

#include <tqwidget.h>
#include "documentitem.h"

class TDEActionCollection;
class TDEToggleAction;
class TDEFontAction;
class TDEFontSizeAction;
class TDEToolBar;
class KSpell;
class KSpellConfig;
class DSTextEdit;
class TokenProvider;

class MultiLineEditor : public TQWidget {
    Q_OBJECT
  
    public:
        MultiLineEditor( TokenProvider* token, TQWidget *parent=0, const char *name=0);
        ~MultiLineEditor();
        TQString text();
        void setText( const TQString & t );
        
    private slots:
        void setupActions();
        void updateActions();
        void spellCheckDone(const TQString & buffer);

        void save();
        void updateFont();
        void updateCharFmt();
        void updateAligment();
        void formatColor();
        void checkSpelling();
        void setAlignLeft( bool yes );
        void setAlignRight( bool yes );
        void setAlignCenter( bool yes );
        void setAlignJustify( bool yes );               
        void insertNewField();
        
    protected:
        TokenProvider* m_token;

	DSTextEdit* editor;
        
        TDEActionCollection* ac;
        
        TDEToggleAction *action_bold;
        TDEToggleAction *action_italic;
        TDEToggleAction *action_underline;

        TDEFontAction *action_font;
        TDEFontSizeAction *action_font_size;

        TDEToggleAction *action_align_left;
        TDEToggleAction *action_align_right;
        TDEToggleAction *action_align_center;
        TDEToggleAction *action_align_justify;

        TDEToolBar* toolBar;
        TDEToolBar* tool2Bar;
        TDEToolBar* tool3Bar;

        KSpell* spell;
};

#endif
